Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1060)

Unified Diff: lib/src/codegen/js_names.dart

Issue 1111803005: fix #159, static renames for caller/arguments (Closed) Base URL: git@github.com:dart-lang/dev_compiler.git@master
Patch Set: Created 5 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « lib/src/codegen/js_codegen.dart ('k') | test/codegen/expect/names.js » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: lib/src/codegen/js_names.dart
diff --git a/lib/src/codegen/js_names.dart b/lib/src/codegen/js_names.dart
index 2ca5fe2ab47ab031366d4dd646d2d0e227491628..9d03bc37cb69d7939447509fe15f37d92c391ac4 100644
--- a/lib/src/codegen/js_names.dart
+++ b/lib/src/codegen/js_names.dart
@@ -231,9 +231,9 @@ bool invalidVariableName(String keyword, {bool strictMode: true}) {
return false;
}
/// Returns true for invalid static method names in strict mode.
/// In particular, "caller" "callee" and "arguments" cannot be used.
-bool invalidStaticMethodName(String name) {
+bool invalidStaticFieldName(String name) {
switch (name) {
case "arguments":
case "caller":
@@ -231,9 +231,9 @@ bool invalidVariableName(String keyword, {bool strictMode: true}) {
return false;
}
-/// Returns true for invalid static method names in strict mode.
+/// Returns true for invalid static field names in strict mode.
/// In particular, "caller" "callee" and "arguments" cannot be used.
« no previous file with comments | « lib/src/codegen/js_codegen.dart ('k') | test/codegen/expect/names.js » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698